# Credits

## Development Lead

* Kipling ([@KipCrossing](https://github.com/KipCrossing))

## Collaborators

* Trevor James Smith ([@Zeitsperre](https://github.com/Zeitsperre))

## Contributors

* Feel free to add yourself!
